# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quality_test.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import shared_types_pb2 as shared__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12quality_test.proto\x12*ProSuite.Microservices.Definitions.QA.Test\x1a\x12shared_types.proto\"\xa5\x02\n\x12\x45xecuteTestRequest\x12K\n\nworkspaces\x18\x01 \x03(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.WorkspaceMsg\x12S\n\x0finvolved_tables\x18\x02 \x03(\x0b\x32:.ProSuite.Microservices.Definitions.QA.Test.TestDatasetMsg\x12\x46\n\tperimeter\x18\x03 \x01(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.ShapeMsg\x12\x11\n\ttest_name\x18\x04 \x01(\t\x12\x12\n\nparameters\x18\x05 \x03(\t\"\xcf\x01\n\x13\x45xecuteTestResponse\x12\x1b\n\x13service_call_status\x18\x01 \x01(\x05\x12M\n\x08progress\x18\x02 \x01(\x0b\x32;.ProSuite.Microservices.Definitions.QA.Test.TestProgressMsg\x12L\n\x06issues\x18\x03 \x03(\x0b\x32<.ProSuite.Microservices.Definitions.QA.Test.DetectedIssueMsg\"\x80\x01\n\x0eTestDatasetMsg\x12S\n\x10\x63lass_definition\x18\x01 \x01(\x0b\x32\x39.ProSuite.Microservices.Definitions.Shared.ObjectClassMsg\x12\x19\n\x11\x66ilter_expression\x18\x02 \x01(\t\"_\n\x0fTestProgressMsg\x12\x1c\n\x14progress_total_steps\x18\x01 \x01(\x05\x12\x1d\n\x15progress_current_step\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xdb\x02\n\x10\x44\x65tectedIssueMsg\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12K\n\x0eissue_geometry\x18\x02 \x01(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.ShapeMsg\x12\x15\n\rissue_code_id\x18\x03 \x01(\t\x12\x1e\n\x16issue_code_description\x18\x04 \x01(\t\x12X\n\x10involved_objects\x18\x05 \x03(\x0b\x32>.ProSuite.Microservices.Definitions.QA.Test.InvolvedObjectsMsg\x12\x16\n\x0estop_condition\x18\x06 \x01(\x08\x12\x1a\n\x12\x61\x66\x66\x65\x63ted_component\x18\x07 \x01(\t\x12 \n\x18\x63reation_date_time_ticks\x18\x08 \x01(\x03\"t\n\x12InvolvedObjectsMsg\x12J\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x39.ProSuite.Microservices.Definitions.Shared.ObjectClassMsg\x12\x12\n\nobject_ids\x18\x02 \x03(\x03\x32\xa2\x01\n\x0fQualityTestGrpc\x12\x8e\x01\n\x07\x45xecute\x12>.ProSuite.Microservices.Definitions.QA.Test.ExecuteTestRequest\x1a?.ProSuite.Microservices.Definitions.QA.Test.ExecuteTestResponse\"\x00\x30\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'quality_test_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXECUTETESTREQUEST._serialized_start=87
  _EXECUTETESTREQUEST._serialized_end=380
  _EXECUTETESTRESPONSE._serialized_start=383
  _EXECUTETESTRESPONSE._serialized_end=590
  _TESTDATASETMSG._serialized_start=593
  _TESTDATASETMSG._serialized_end=721
  _TESTPROGRESSMSG._serialized_start=723
  _TESTPROGRESSMSG._serialized_end=818
  _DETECTEDISSUEMSG._serialized_start=821
  _DETECTEDISSUEMSG._serialized_end=1168
  _INVOLVEDOBJECTSMSG._serialized_start=1170
  _INVOLVEDOBJECTSMSG._serialized_end=1286
  _QUALITYTESTGRPC._serialized_start=1289
  _QUALITYTESTGRPC._serialized_end=1451
# @@protoc_insertion_point(module_scope)
