# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: shared_qa.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import shared_types_pb2 as shared__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fshared_qa.proto\x12%ProSuite.Microservices.Definitions.QA\x1a\x12shared_types.proto\"\xda\x01\n\x0eWorkContextMsg\x12\x0e\n\x06\x64\x64x_id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12J\n\tworkspace\x18\x03 \x01(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.WorkspaceMsg\x12\x14\n\x0cversion_name\x18\x06 \x01(\t\x12\x1c\n\x14verified_dataset_ids\x18\x07 \x03(\x05\x12\x14\n\x0c\x63ontext_type\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontext_name\x18\x05 \x01(\t\"\xe0\x02\n\x17QualitySpecificationMsg\x12\"\n\x18quality_specification_id\x18\x01 \x01(\x05H\x00\x12\"\n\x18well_known_specification\x18\x02 \x01(\x05H\x00\x12^\n\x11xml_specification\x18\x03 \x01(\x0b\x32\x41.ProSuite.Microservices.Definitions.QA.XmlQualitySpecificationMsgH\x00\x12l\n\x1c\x63ondition_list_specification\x18\x05 \x01(\x0b\x32\x44.ProSuite.Microservices.Definitions.QA.ConditionListSpecificationMsgH\x00\x12\x1e\n\x16\x65xcluded_condition_ids\x18\x04 \x03(\x05\x42\x0f\n\rspecification\"p\n\x1aXmlQualitySpecificationMsg\x12\x0b\n\x03xml\x18\x01 \x01(\t\x12#\n\x1bselected_specification_name\x18\x02 \x01(\t\x12 \n\x18\x64\x61ta_source_replacements\x18\x03 \x03(\t\"\xe7\x01\n\x1d\x43onditionListSpecificationMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12W\n\x08\x65lements\x18\x03 \x03(\x0b\x32\x45.ProSuite.Microservices.Definitions.QA.QualitySpecificationElementMsg\x12J\n\x0c\x64\x61ta_sources\x18\x04 \x03(\x0b\x32\x34.ProSuite.Microservices.Definitions.QA.DataSourceMsg\"m\n\rDataSourceMsg\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x63\x61talog_path\x18\x02 \x01(\t\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x14\n\x0cschema_owner\x18\x05 \x01(\t\"\xb3\x01\n\x1eQualitySpecificationElementMsg\x12M\n\tcondition\x18\x01 \x01(\x0b\x32:.ProSuite.Microservices.Definitions.QA.QualityConditionMsg\x12\x14\n\x0c\x61llow_errors\x18\x02 \x01(\x08\x12\x15\n\rstop_on_error\x18\x03 \x01(\x08\x12\x15\n\rcategory_name\x18\x05 \x01(\t\"\xc5\x02\n\x13QualityConditionMsg\x12\x14\n\x0c\x63ondition_id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14test_descriptor_name\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12G\n\nparameters\x18\x06 \x03(\x0b\x32\x33.ProSuite.Microservices.Definitions.QA.ParameterMsg\x12`\n\x17\x63ondition_issue_filters\x18\x07 \x03(\x0b\x32?.ProSuite.Microservices.Definitions.QA.InstanceConfigurationMsg\x12\x1f\n\x17issue_filter_expression\x18\x08 \x01(\t\"\xc1\x01\n\x18InstanceConfigurationMsg\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x18instance_descriptor_name\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12G\n\nparameters\x18\x06 \x03(\x0b\x32\x33.ProSuite.Microservices.Definitions.QA.ParameterMsg\"\xcd\x01\n\x0cParameterMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12T\n\x0btransformer\x18\x06 \x01(\x0b\x32?.ProSuite.Microservices.Definitions.QA.InstanceConfigurationMsg\x12\x14\n\x0cwhere_clause\x18\x03 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x04 \x01(\t\x12\x1e\n\x16used_as_reference_data\x18\x05 \x01(\x08\"\xbe\x01\n\x15InstanceDescriptorMsg\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12S\n\x10\x63lass_descriptor\x18\x04 \x01(\x0b\x32\x39.ProSuite.Microservices.Definitions.QA.ClassDescriptorMsg\x12\x13\n\x0b\x63onstructor\x18\x05 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\">\n\x12\x43lassDescriptorMsg\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\x15\n\rassembly_name\x18\x02 \x01(\t\"\xda\x05\n\x19VerificationParametersMsg\x12\x11\n\ttile_size\x18\x01 \x01(\x01\x12\x46\n\tperimeter\x18\x02 \x01(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.ShapeMsg\x12*\n\"write_detailed_verification_report\x18\x03 \x01(\x08\x12 \n\x18verification_report_path\x18\x04 \x01(\t\x12\x18\n\x10html_report_path\x18\x05 \x01(\t\x12\x1a\n\x12html_template_path\x18\x06 \x01(\t\x12\x1b\n\x13issue_file_gdb_path\x18\x07 \x01(\t\x12\x33\n+store_related_geometry_for_table_row_issues\x18\x08 \x01(\x08\x12\x30\n(filter_table_rows_using_related_geometry\x18\t \x01(\x08\x12\x1f\n\x17override_allowed_errors\x18\n \x01(\x08\x12\'\n\x1freport_issues_outside_perimeter\x18\x0b \x01(\x08\x12/\n\'force_full_scan_for_non_container_tests\x18\x0c \x01(\x08\x12$\n\x1csave_verification_statistics\x18\r \x01(\x08\x12 \n\x18report_unused_exceptions\x18\x0e \x01(\x08\x12!\n\x19report_invalid_exceptions\x18\x0f \x01(\x08\x12<\n4invalidate_exceptions_if_any_involved_object_changed\x18\x10 \x01(\x08\x12\x36\n.invalidate_exceptions_if_condition_was_updated\x18\x11 \x01(\x08\"q\n\x07GdbData\x12\x18\n\x10gdb_object_count\x18\x04 \x01(\x03\x12L\n\x0bgdb_objects\x18\x03 \x03(\x0b\x32\x37.ProSuite.Microservices.Definitions.Shared.GdbObjectMsg\"\xc0\x02\n\x0b\x44\x61taRequest\x12\x44\n\tclass_def\x18\x01 \x01(\x0b\x32/.ProSuite.Microservices.Definitions.QA.ClassDefH\x00\x12V\n\rrel_query_def\x18\x02 \x01(\x0b\x32=.ProSuite.Microservices.Definitions.QA.RelationshipClassQueryH\x00\x12\x14\n\x0cwhere_clause\x18\x03 \x01(\t\x12L\n\x0fsearch_geometry\x18\x04 \x01(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.ShapeMsg\x12\x12\n\nsub_fields\x18\x05 \x01(\t\x12\x12\n\ncount_only\x18\x06 \x01(\x08\x42\x07\n\x05table\":\n\x08\x43lassDef\x12\x14\n\x0c\x63lass_handle\x18\x01 \x01(\x03\x12\x18\n\x10workspace_handle\x18\x02 \x01(\x03\"\x8c\x01\n\x16RelationshipClassQuery\x12\x1f\n\x17relationship_class_name\x18\x01 \x01(\t\x12\x18\n\x10workspace_handle\x18\x02 \x01(\x03\x12\x0e\n\x06tables\x18\x03 \x03(\t\x12\x11\n\tjoin_type\x18\x04 \x01(\x05\x12\x14\n\x0cwhere_clause\x18\x05 \x01(\t\"\xba\x01\n\tSchemaMsg\x12T\n\x11\x63lass_definitions\x18\x01 \x03(\x0b\x32\x39.ProSuite.Microservices.Definitions.Shared.ObjectClassMsg\x12W\n\x14relclass_definitions\x18\x02 \x03(\x0b\x32\x39.ProSuite.Microservices.Definitions.Shared.ObjectClassMsg\"\x87\x01\n\rSchemaRequest\x12\x13\n\x0b\x64\x61taset_ids\x18\x01 \x03(\x05\x12\x61\n\x1arelationship_class_queries\x18\x02 \x03(\x0b\x32=.ProSuite.Microservices.Definitions.QA.RelationshipClassQuery\"\xc5\x03\n\x17VerificationProgressMsg\x12\x15\n\rprogress_type\x18\x01 \x01(\x05\x12\x15\n\rprogress_step\x18\x02 \x01(\x05\x12$\n\x1coverall_progress_total_steps\x18\x03 \x01(\x05\x12%\n\x1doverall_progress_current_step\x18\x04 \x01(\x05\x12%\n\x1d\x64\x65tailed_progress_total_steps\x18\x05 \x01(\x05\x12\'\n\x1f\x64\x65tailed_progress__current_step\x18\x06 \x01(\x05\x12\x1f\n\x17processing_step_message\x18\x07 \x01(\t\x12K\n\x0b\x63urrent_box\x18\x08 \x01(\x0b\x32\x36.ProSuite.Microservices.Definitions.Shared.EnvelopeMsg\x12I\n\ttotal_box\x18\t \x01(\x0b\x32\x36.ProSuite.Microservices.Definitions.Shared.EnvelopeMsg\x12\x0f\n\x07message\x18\n \x01(\t\x12\x15\n\rmessage_level\x18\x0b \x01(\x05\"\xa0\x03\n\x08IssueMsg\x12\x14\n\x0c\x63ondition_id\x18\x01 \x01(\x05\x12K\n\x0eissue_geometry\x18\x02 \x01(\x0b\x32\x33.ProSuite.Microservices.Definitions.Shared.ShapeMsg\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x15\n\rissue_code_id\x18\x05 \x01(\t\x12\x1e\n\x16issue_code_description\x18\x06 \x01(\t\x12P\n\x0finvolved_tables\x18\x07 \x03(\x0b\x32\x37.ProSuite.Microservices.Definitions.QA.InvolvedTableMsg\x12\x1c\n\x14legacy_involved_rows\x18\x08 \x01(\t\x12\x11\n\tallowable\x18\t \x01(\x08\x12\x16\n\x0estop_condition\x18\n \x01(\x08\x12\x1a\n\x12\x61\x66\x66\x65\x63ted_component\x18\x0b \x01(\t\x12 \n\x18\x63reation_date_time_ticks\x18\x0c \x01(\x03\x12\x0c\n\x04test\x18\r \x01(\x05\":\n\x10InvolvedTableMsg\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x12\n\nobject_ids\x18\x02 \x03(\x03\"\xb8\x04\n\x16QualityVerificationMsg\x12\x1d\n\x15saved_verification_id\x18\x01 \x01(\x05\x12\x18\n\x10specification_id\x18\x02 \x01(\x05\x12\x1a\n\x12specification_name\x18\x03 \x01(\t\x12!\n\x19specification_description\x18\x04 \x01(\t\x12\x11\n\tuser_name\x18\x05 \x01(\t\x12\x18\n\x10start_time_ticks\x18\x06 \x01(\x03\x12\x16\n\x0e\x65nd_time_ticks\x18\x07 \x01(\x03\x12\x11\n\tfulfilled\x18\x08 \x01(\x08\x12\x11\n\tcancelled\x18\t \x01(\x08\x12\x1e\n\x16processor_time_seconds\x18\n \x01(\x01\x12\x14\n\x0c\x63ontext_type\x18\x0b \x01(\t\x12\x14\n\x0c\x63ontext_name\x18\x0c \x01(\t\x12!\n\x19rows_with_stop_conditions\x18\r \x01(\x05\x12g\n\x17\x63ondition_verifications\x18\x0e \x03(\x0b\x32\x46.ProSuite.Microservices.Definitions.QA.QualityConditionVerificationMsg\x12\x63\n\x15verification_datasets\x18\x0f \x03(\x0b\x32\x44.ProSuite.Microservices.Definitions.QA.QualityVerificationDatasetMsg\"\xcd\x01\n\x1fQualityConditionVerificationMsg\x12\x1c\n\x14quality_condition_id\x18\x01 \x01(\x05\x12\x19\n\x11stop_condition_id\x18\x02 \x01(\x05\x12\x11\n\tfulfilled\x18\x03 \x01(\x08\x12\x13\n\x0b\x65rror_count\x18\x04 \x01(\x05\x12\x14\n\x0c\x65xecute_time\x18\x05 \x01(\x01\x12\x18\n\x10row_execute_time\x18\x06 \x01(\x01\x12\x19\n\x11tile_execute_time\x18\x07 \x01(\x01\"F\n\x1dQualityVerificationDatasetMsg\x12\x12\n\ndataset_id\x18\x01 \x01(\x05\x12\x11\n\tload_time\x18\x02 \x01(\x01\"0\n\x06LogMsg\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x15\n\rmessage_level\x18\x04 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'shared_qa_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKCONTEXTMSG._serialized_start=79
  _WORKCONTEXTMSG._serialized_end=297
  _QUALITYSPECIFICATIONMSG._serialized_start=300
  _QUALITYSPECIFICATIONMSG._serialized_end=652
  _XMLQUALITYSPECIFICATIONMSG._serialized_start=654
  _XMLQUALITYSPECIFICATIONMSG._serialized_end=766
  _CONDITIONLISTSPECIFICATIONMSG._serialized_start=769
  _CONDITIONLISTSPECIFICATIONMSG._serialized_end=1000
  _DATASOURCEMSG._serialized_start=1002
  _DATASOURCEMSG._serialized_end=1111
  _QUALITYSPECIFICATIONELEMENTMSG._serialized_start=1114
  _QUALITYSPECIFICATIONELEMENTMSG._serialized_end=1293
  _QUALITYCONDITIONMSG._serialized_start=1296
  _QUALITYCONDITIONMSG._serialized_end=1621
  _INSTANCECONFIGURATIONMSG._serialized_start=1624
  _INSTANCECONFIGURATIONMSG._serialized_end=1817
  _PARAMETERMSG._serialized_start=1820
  _PARAMETERMSG._serialized_end=2025
  _INSTANCEDESCRIPTORMSG._serialized_start=2028
  _INSTANCEDESCRIPTORMSG._serialized_end=2218
  _CLASSDESCRIPTORMSG._serialized_start=2220
  _CLASSDESCRIPTORMSG._serialized_end=2282
  _VERIFICATIONPARAMETERSMSG._serialized_start=2285
  _VERIFICATIONPARAMETERSMSG._serialized_end=3015
  _GDBDATA._serialized_start=3017
  _GDBDATA._serialized_end=3130
  _DATAREQUEST._serialized_start=3133
  _DATAREQUEST._serialized_end=3453
  _CLASSDEF._serialized_start=3455
  _CLASSDEF._serialized_end=3513
  _RELATIONSHIPCLASSQUERY._serialized_start=3516
  _RELATIONSHIPCLASSQUERY._serialized_end=3656
  _SCHEMAMSG._serialized_start=3659
  _SCHEMAMSG._serialized_end=3845
  _SCHEMAREQUEST._serialized_start=3848
  _SCHEMAREQUEST._serialized_end=3983
  _VERIFICATIONPROGRESSMSG._serialized_start=3986
  _VERIFICATIONPROGRESSMSG._serialized_end=4439
  _ISSUEMSG._serialized_start=4442
  _ISSUEMSG._serialized_end=4858
  _INVOLVEDTABLEMSG._serialized_start=4860
  _INVOLVEDTABLEMSG._serialized_end=4918
  _QUALITYVERIFICATIONMSG._serialized_start=4921
  _QUALITYVERIFICATIONMSG._serialized_end=5489
  _QUALITYCONDITIONVERIFICATIONMSG._serialized_start=5492
  _QUALITYCONDITIONVERIFICATIONMSG._serialized_end=5697
  _QUALITYVERIFICATIONDATASETMSG._serialized_start=5699
  _QUALITYVERIFICATIONDATASETMSG._serialized_end=5769
  _LOGMSG._serialized_start=5771
  _LOGMSG._serialized_end=5819
# @@protoc_insertion_point(module_scope)
